@@ -23,13 +23,8 @@
 #' 
 #' # clean up cars.df
 #' delete(cars.df)
-select.disk.frame <- function(.data, ...) {
-  quo_dotdotdot = rlang::enquos(...)
-  cmap(.data, ~{
-    code = rlang::quo(dplyr::select(.x, !!!quo_dotdotdot))
-    rlang::eval_tidy(code)
-  }, lazy = TRUE)
-}
+select.disk.frame <- create_chunk_mapper(dplyr::select)
+
 
 #' @export
 #' @rdname dplyr_verbs
@@ -43,7 +38,6 @@ filter.disk.frame <- create_chunk_mapper(dplyr::filter)
 #' @export
 #' @rdname dplyr_verbs
 #' @importFrom future getGlobalsAndPackages
-#' @importFrom rlang eval_tidy quo enquos
 #' @importFrom dplyr mutate
 mutate.disk.frame <- create_chunk_mapper(dplyr::mutate)
 
@@ -65,21 +59,21 @@ arrange.disk.frame =create_chunk_mapper(dplyr::arrange, warning_msg="`arrange.di
 #' @rdname dplyr_verbs
 chunk_arrange <- create_chunk_mapper(dplyr::arrange)
 
-
 # TODO family is not required is group-by
 # TODO alot of these .disk.frame functions are not generic
 
 
+# TODO make this work like in dplyr
 #' #' @export
 #' #' @importFrom dplyr add_count
 #' #' @rdname dplyr_verbs
 #' add_count.disk.frame <- create_chunk_mapper(dplyr::add_count)
 
 
-#' @export
-#' @importFrom dplyr add_tally
-#' @rdname dplyr_verbs
-add_tally.disk.frame <- create_chunk_mapper(dplyr::add_tally)
+#' #' @export
+#' #' @importFrom dplyr add_tally
+#' #' @rdname dplyr_verbs
+#' add_tally.disk.frame <- create_chunk_mapper(dplyr::add_tally)
 
 
 #' @export
@@ -94,10 +88,10 @@ chunk_summarize <- create_chunk_mapper(dplyr::summarize)
 chunk_summarise <- create_chunk_mapper(dplyr::summarise)
 
 
-#' @export
-#' @rdname dplyr_verbs
-#' @importFrom dplyr do
-do.disk.frame <- create_chunk_mapper(dplyr::do)
+#' #' @export
+#' #' @rdname dplyr_verbs
+#' #' @importFrom dplyr do
+#' do.disk.frame <- create_chunk_mapper(dplyr::do)
 
 
 #' @export
@@ -148,37 +142,3 @@ chunk_ungroup = create_chunk_mapper(dplyr::ungroup)
 glimpse.disk.frame <- function(.data, ...) {
   glimpse(head(.data, ...), ...)
 }
-
-# Internal methods
-# @param .data the data
-# @param cmd the function to record
-record <- function(.data, cmd){
-  attr(.data,"lazyfn") <- c(attr(.data,"lazyfn"), list(cmd))
-  .data
-}
-
-# Internal methods
-# @param .data the disk.frame
-# @param cmds the list of function to play back
-play <- function(.data, cmds=NULL) {
-  for (cmd in cmds){
-    if (typeof(cmd) == "closure") {
-      .data <- cmd(.data)
-    } else {
-      # create a temporary environment 
-      an_env = new.env(parent = environment())
-      
-      ng = names(cmd$vars_and_pkgs$globals)
-      
-      if(length(ng) > 0) {
-        for(i in 1:length(cmd$vars_and_pkgs$globals)) {
-          g = cmd$vars_and_pkgs$globals[[i]]
-          assign(ng[i], g, pos = an_env)
-        }
-      }
-      
-      .data <- do.call(cmd$func, c(list(.data),cmd$dotdotdot), envir = an_env)
-    }
-  }
-  .data
-}
