@@ -34,7 +34,7 @@ nchunk.disk.frame <- function(df, ...) {
 #' @export
 nchunks.disk.frame <- function(df, skip.ready.check = FALSE, ...) {
   #if(!skip.ready.check) stopifnot(is_ready(df))
-  fpath <- attr(df,"path")
+  fpath <- attr(df,"path", exact=TRUE)
   if(is.dir.disk.frame(df)) {
     return(length(fs::dir_ls(fpath, type="file")))
   } else {
